"""
Search models for CCS library.
"""

from ccs.models.search.filter_search import FilterSearch
from ccs.models.search.freeschema_query import FreeschemaQuery

__all__ = [
    "FilterSearch",
    "FreeschemaQuery",
]
